"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TreeView = void 0;
var _react = _interopRequireWildcard(require("react"));
var _NodeList = _interopRequireDefault(require("./components/NodeList"));
var _helpers = require("./helpers");
var _signalsReact = require("@preact/signals-react");
var _global = require("./signals/global.signals");
var _reactNative = require("react-native");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const _TreeView = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    data,
    onCheck,
    onExpand,
    preselectedIds,
    treeFlashListProps,
    checkBoxViewStyleProps,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  (0, _react.useImperativeHandle)(ref, () => ({
    selectAll: _helpers.selectAll,
    unselectAll: _helpers.unselectAll,
    selectAllFiltered: _helpers.selectAllFiltered,
    unselectAllFiltered: _helpers.unselectAllFiltered,
    expandAll: _helpers.expandAll,
    collapseAll: _helpers.collapseAll,
    setSearchText
  }));
  function setSearchText(text) {
    let keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ["name"];
    _global.searchText.value = text;
    _global.searchKeys.value = keys;
  }
  (0, _react.useEffect)(() => {
    _global.globalData.value = data;
    (0, _helpers.initializeNodeMaps)(data, preselectedIds);
  }, [data, preselectedIds]);
  const disposeCheckedStateEffect = _react.default.useMemo(() => {
    return (0, _signalsReact.effect)(() => {
      onCheck && onCheck(Array.from(_global.state.value.checked));
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const disposeExpandedStateEffect = _react.default.useMemo(() => {
    return (0, _signalsReact.effect)(() => {
      onExpand && onExpand(Array.from(_global.expanded.value));
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const disposeSearchStateEffect = _react.default.useMemo(() => {
    return (0, _signalsReact.effect)(() => {
      if (_global.searchText.value) {
        _reactNative.InteractionManager.runAfterInteractions(() => {
          _global.expanded.value = new Set(_global.globalData.value.flatMap(item => getIds(item)));
        });
      } else {
        _reactNative.InteractionManager.runAfterInteractions(() => {
          _global.expanded.value = new Set();
        });
      }
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  (0, _react.useEffect)(() => {
    return () => {
      // Cleanup all global signals and signal effects
      disposeCheckedStateEffect();
      disposeExpandedStateEffect();
      disposeSearchStateEffect();
      (0, _global.cleanUpGlobalSignals)();
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const getIds = _react.default.useCallback(node => {
    if (!node.children || node.children.length === 0) {
      return [node.id];
    } else {
      return [node.id, ...node.children.flatMap(item => getIds(item))];
    }
  }, []);
  return /*#__PURE__*/_react.default.createElement(_NodeList.default, {
    treeFlashListProps: treeFlashListProps,
    checkBoxViewStyleProps: checkBoxViewStyleProps,
    CheckboxComponent: CheckboxComponent,
    ExpandCollapseIconComponent: ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
  });
});
const TreeView = /*#__PURE__*/_react.default.memo(_TreeView);
exports.TreeView = TreeView;
//# sourceMappingURL=TreeView.js.map