"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _signalsReact = require("@preact/signals-react");
var _flashList = require("@shopify/flash-list");
var _global = require("../signals/global.signals");
var _helpers = require("../helpers");
var _CheckboxView = require("./CheckboxView");
var _CustomExpandCollapseIcon = _interopRequireDefault(require("./CustomExpandCollapseIcon"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const NodeList = /*#__PURE__*/_react.default.memo(_NodeList);
var _default = NodeList;
exports.default = _default;
function _NodeList(props) {
  const {
    treeFlashListProps,
    checkBoxViewStyleProps,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  const filteredTree = _react.default.useMemo(() => {
    return (0, _signalsReact.computed)(() => {
      const searchTrimmed = _global.searchText.value.trim().toLowerCase();
      const filterTreeData = _nodes => {
        let filtered = [];
        for (let node of _nodes) {
          if (!searchTrimmed || (0, _helpers.doesNodeContainSearchTerm)(node, searchTrimmed, _global.searchKeys.value)) {
            // If node itself matches, include it and all its descendants
            filtered.push(node);
          } else if (node.children) {
            // If node does not match, check its children and include them if they match
            const childMatches = filterTreeData(node.children);
            if (childMatches.length > 0) {
              // If any children match, include the node, replacing its children with the matching ones
              filtered.push({
                ...node,
                children: childMatches
              });
            }
          }
        }
        return filtered;
      };
      return filterTreeData(_global.globalData.value);
    });
  }, []);
  const flattenedFilteredNodes = _react.default.useMemo(() => {
    return (0, _signalsReact.computed)(() => {
      const flattenTreeData = function (_nodes) {
        let level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
        let flattened = [];
        for (let node of _nodes) {
          flattened.push({
            ...node,
            level
          });
          if (node.children && _global.expanded.value.has(node.id)) {
            flattened = [...flattened, ...flattenTreeData(node.children, level + 1)];
          }
        }
        return flattened;
      };
      return flattenTreeData(filteredTree.value);
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  _react.default.useEffect(() => {
    (0, _signalsReact.effect)(() => {
      const allLeafIds = [];
      const getLeafNodes = _nodes => {
        for (let node of _nodes) {
          if (node.children) {
            getLeafNodes(node.children);
          } else {
            allLeafIds.push(node.id);
          }
        }
      };
      getLeafNodes(filteredTree.value);
      _global.innerMostChildrenIds.value = allLeafIds;
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const nodeRenderer = _react.default.useCallback(_ref => {
    let {
      item
    } = _ref;
    return /*#__PURE__*/_react.default.createElement(Node, {
      node: item,
      level: item.level || 0,
      checkBoxViewStyleProps: checkBoxViewStyleProps,
      CheckboxComponent: CheckboxComponent,
      ExpandCollapseIconComponent: ExpandCollapseIconComponent,
      ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
    });
  }, [CheckboxComponent, ExpandCollapseIconComponent, ExpandCollapseTouchableComponent, checkBoxViewStyleProps]);
  const keyExtractor = _react.default.useCallback(item => item.id, []);
  return /*#__PURE__*/_react.default.createElement(_flashList.FlashList, _extends({
    estimatedItemSize: 36,
    removeClippedSubviews: true,
    keyboardShouldPersistTaps: "handled",
    drawDistance: 50,
    data: flattenedFilteredNodes.value,
    renderItem: nodeRenderer,
    keyExtractor: keyExtractor,
    ListHeaderComponent: /*#__PURE__*/_react.default.createElement(HeaderFooterView, null),
    ListFooterComponent: /*#__PURE__*/_react.default.createElement(HeaderFooterView, null)
  }, treeFlashListProps));
}
;
function HeaderFooterView() {
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.defaultHeaderFooter
  });
}
const Node = /*#__PURE__*/_react.default.memo(_Node);
function _Node(props) {
  var _node$value$children;
  const {
    node: _node,
    level,
    checkBoxViewStyleProps,
    ExpandCollapseIconComponent = _CustomExpandCollapseIcon.default,
    CheckboxComponent = _CheckboxView.CheckboxView,
    ExpandCollapseTouchableComponent = _reactNative.TouchableOpacity
  } = props;
  const node = (0, _signalsReact.useSignal)(_node);
  _react.default.useEffect(() => {
    node.value = _node;
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [_node]);
  const isChecked = (0, _signalsReact.useComputed)(() => _global.state.value.checked.has(node.value.id));
  const isIndeterminate = (0, _signalsReact.useComputed)(() => _global.state.value.indeterminate.has(node.value.id));
  const value = (0, _signalsReact.useComputed)(() => {
    if (isIndeterminate.value) {
      return 'indeterminate';
    } else if (isChecked.value) {
      return true;
    } else {
      return false;
    }
  });
  const isExpanded = (0, _signalsReact.useComputed)(() => _global.expanded.value.has(node.value.id));
  const _onToggleExpand = _react.default.useCallback(() => {
    (0, _helpers.handleToggleExpand)(node.value.id);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const _onCheck = _react.default.useCallback(() => {
    (0, _helpers.toggleCheckboxes)([node.value.id]);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.nodeParentView, {
      marginLeft: level * 15
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nodeCheckboxAndArrowRow
  }, /*#__PURE__*/_react.default.createElement(CheckboxComponent, _extends({
    text: node.value.name,
    onValueChange: _onCheck,
    value: value.value
  }, checkBoxViewStyleProps)), (_node$value$children = node.value.children) !== null && _node$value$children !== void 0 && _node$value$children.length ? /*#__PURE__*/_react.default.createElement(ExpandCollapseTouchableComponent, {
    style: styles.nodeExpandableArrowTouchable,
    onPress: _onToggleExpand
  }, /*#__PURE__*/_react.default.createElement(ExpandCollapseIconComponent, {
    isExpanded: isExpanded.value
  })) : null));
}
;
const styles = _reactNative.StyleSheet.create({
  defaultHeaderFooter: {
    padding: 5
  },
  nodeParentView: {
    flex: 1
  },
  nodeExpandableArrowTouchable: {
    flex: 1
  },
  nodeCheckboxAndArrowRow: {
    flexDirection: 'row',
    alignItems: 'center',
    minWidth: "100%"
  }
});
//# sourceMappingURL=NodeList.js.map