"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializeNodeMaps = initializeNodeMaps;
var _global = require("../signals/global.signals");
var _toggleCheckbox = require("./toggleCheckbox.helper");
/**
 * Initialize the maps for tracking tree nodes and their parent-child relationships.
 *
 * This function is intended to be called once, during component initialization, 
 * with the initial tree data and any preselected node IDs.
 *
 * @param initialData - An array of TreeNode objects that represent the initial tree structure.
 * @param preselectedIds - An optional array of TreeNode IDs that should be preselected.
 */
function initializeNodeMaps(initialData) {
  let preselectedIds = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  /**
   * Recursively processes nodes, adding them to the nodeMap and childToParentMap.
   *
   * @param nodes - An array of TreeNode objects to be processed.
   * @param parentId - The ID of the parent node, if applicable.
   */
  const processNodes = function (nodes) {
    let parentId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    nodes.forEach(node => {
      // Each node is added to the nodeMap with its ID as the key
      _global.nodeMap.value.set(node.id, node);
      // If the node has a parent, its ID is mapped to the parent's ID in the childToParentMap
      if (parentId) _global.childToParentMap.value.set(node.id, parentId);
      // If the node has children, recursively process them
      if (node.children) processNodes(node.children, node.id);
    });
  };

  // Begin processing with the initial tree data
  processNodes(initialData);

  // Check any preselected nodes
  (0, _toggleCheckbox.toggleCheckboxes)(preselectedIds, true);
}
//# sourceMappingURL=initNodeMap.helper.js.map