"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.selectAll = selectAll;
exports.selectAllFiltered = selectAllFiltered;
exports.unselectAll = unselectAll;
exports.unselectAllFiltered = unselectAllFiltered;
var _global = require("../signals/global.signals");
var _toggleCheckbox = require("./toggleCheckbox.helper");
/**
 * Selects all nodes that are currently visible due to the applied filter.
 * 
 * If there is no search text, then it selects all nodes; otherwise, it selects all visible nodes.
 */
function selectAllFiltered() {
  // If there's no search text, select all nodes
  if (!_global.searchText.value) {
    selectAll();
  } else {
    // If there's search text, only select the visible nodes
    (0, _toggleCheckbox.toggleCheckboxes)(_global.innerMostChildrenIds.value, true);
  }
}
;

/**
 * Unselects all nodes that are currently visible due to the applied filter.
 * 
 * If there is no search text, then it unselects all nodes; otherwise, it unselects all visible nodes.
 */
function unselectAllFiltered() {
  // If there's no search text, unselect all nodes
  if (!_global.searchText.value) {
    unselectAll();
  } else {
    // If there's search text, only unselect the visible nodes
    (0, _toggleCheckbox.toggleCheckboxes)(_global.innerMostChildrenIds.value, false);
  }
}
;

/**
 * Selects all nodes in the tree.
 * 
 * This function selects all nodes by adding all node ids to the checked set and clearing the indeterminate set.
 */
function selectAll() {
  // Create a new set containing the ids of all nodes
  const newChecked = new Set(_global.nodeMap.value.keys());
  // Update the state to mark all nodes as checked
  _global.state.value = {
    checked: newChecked,
    indeterminate: new Set()
  };
}
;

/**
 * Unselects all nodes in the tree.
 * 
 * This function unselects all nodes by clearing both the checked and indeterminate sets.
 */
function unselectAll() {
  // Update the state to mark all nodes as unchecked
  _global.state.value = {
    checked: new Set(),
    indeterminate: new Set()
  };
}
;
//# sourceMappingURL=selectAll.helper.js.map