function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { View, StyleSheet, TouchableOpacity } from "react-native";
import { computed, effect, useComputed, useSignal } from "@preact/signals-react";
import { FlashList } from "@shopify/flash-list";
import { expanded, globalData, innerMostChildrenIds, searchKeys, searchText, state } from "../signals/global.signals";
import { doesNodeContainSearchTerm, handleToggleExpand, toggleCheckboxes } from "../helpers";
import { CheckboxView } from "./CheckboxView";
import CustomExpandCollapseIcon from "./CustomExpandCollapseIcon";
const NodeList = /*#__PURE__*/React.memo(_NodeList);
export default NodeList;
function _NodeList(props) {
  const {
    treeFlashListProps,
    checkBoxViewStyleProps,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  const filteredTree = React.useMemo(() => {
    return computed(() => {
      const searchTrimmed = searchText.value.trim().toLowerCase();
      const filterTreeData = _nodes => {
        let filtered = [];
        for (let node of _nodes) {
          if (!searchTrimmed || doesNodeContainSearchTerm(node, searchTrimmed, searchKeys.value)) {
            // If node itself matches, include it and all its descendants
            filtered.push(node);
          } else if (node.children) {
            // If node does not match, check its children and include them if they match
            const childMatches = filterTreeData(node.children);
            if (childMatches.length > 0) {
              // If any children match, include the node, replacing its children with the matching ones
              filtered.push({
                ...node,
                children: childMatches
              });
            }
          }
        }
        return filtered;
      };
      return filterTreeData(globalData.value);
    });
  }, []);
  const flattenedFilteredNodes = React.useMemo(() => {
    return computed(() => {
      const flattenTreeData = function (_nodes) {
        let level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
        let flattened = [];
        for (let node of _nodes) {
          flattened.push({
            ...node,
            level
          });
          if (node.children && expanded.value.has(node.id)) {
            flattened = [...flattened, ...flattenTreeData(node.children, level + 1)];
          }
        }
        return flattened;
      };
      return flattenTreeData(filteredTree.value);
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  React.useEffect(() => {
    effect(() => {
      const allLeafIds = [];
      const getLeafNodes = _nodes => {
        for (let node of _nodes) {
          if (node.children) {
            getLeafNodes(node.children);
          } else {
            allLeafIds.push(node.id);
          }
        }
      };
      getLeafNodes(filteredTree.value);
      innerMostChildrenIds.value = allLeafIds;
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const nodeRenderer = React.useCallback(_ref => {
    let {
      item
    } = _ref;
    return /*#__PURE__*/React.createElement(Node, {
      node: item,
      level: item.level || 0,
      checkBoxViewStyleProps: checkBoxViewStyleProps,
      CheckboxComponent: CheckboxComponent,
      ExpandCollapseIconComponent: ExpandCollapseIconComponent,
      ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
    });
  }, [CheckboxComponent, ExpandCollapseIconComponent, ExpandCollapseTouchableComponent, checkBoxViewStyleProps]);
  const keyExtractor = React.useCallback(item => item.id, []);
  return /*#__PURE__*/React.createElement(FlashList, _extends({
    estimatedItemSize: 36,
    removeClippedSubviews: true,
    keyboardShouldPersistTaps: "handled",
    drawDistance: 50,
    data: flattenedFilteredNodes.value,
    renderItem: nodeRenderer,
    keyExtractor: keyExtractor,
    ListHeaderComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null),
    ListFooterComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null)
  }, treeFlashListProps));
}
;
function HeaderFooterView() {
  return /*#__PURE__*/React.createElement(View, {
    style: styles.defaultHeaderFooter
  });
}
const Node = /*#__PURE__*/React.memo(_Node);
function _Node(props) {
  var _node$value$children;
  const {
    node: _node,
    level,
    checkBoxViewStyleProps,
    ExpandCollapseIconComponent = CustomExpandCollapseIcon,
    CheckboxComponent = CheckboxView,
    ExpandCollapseTouchableComponent = TouchableOpacity
  } = props;
  const node = useSignal(_node);
  React.useEffect(() => {
    node.value = _node;
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [_node]);
  const isChecked = useComputed(() => state.value.checked.has(node.value.id));
  const isIndeterminate = useComputed(() => state.value.indeterminate.has(node.value.id));
  const value = useComputed(() => {
    if (isIndeterminate.value) {
      return 'indeterminate';
    } else if (isChecked.value) {
      return true;
    } else {
      return false;
    }
  });
  const isExpanded = useComputed(() => expanded.value.has(node.value.id));
  const _onToggleExpand = React.useCallback(() => {
    handleToggleExpand(node.value.id);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const _onCheck = React.useCallback(() => {
    toggleCheckboxes([node.value.id]);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.nodeParentView, {
      marginLeft: level * 15
    }]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.nodeCheckboxAndArrowRow
  }, /*#__PURE__*/React.createElement(CheckboxComponent, _extends({
    text: node.value.name,
    onValueChange: _onCheck,
    value: value.value
  }, checkBoxViewStyleProps)), (_node$value$children = node.value.children) !== null && _node$value$children !== void 0 && _node$value$children.length ? /*#__PURE__*/React.createElement(ExpandCollapseTouchableComponent, {
    style: styles.nodeExpandableArrowTouchable,
    onPress: _onToggleExpand
  }, /*#__PURE__*/React.createElement(ExpandCollapseIconComponent, {
    isExpanded: isExpanded.value
  })) : null));
}
;
const styles = StyleSheet.create({
  defaultHeaderFooter: {
    padding: 5
  },
  nodeParentView: {
    flex: 1
  },
  nodeExpandableArrowTouchable: {
    flex: 1
  },
  nodeCheckboxAndArrowRow: {
    flexDirection: 'row',
    alignItems: 'center',
    minWidth: "100%"
  }
});
//# sourceMappingURL=NodeList.js.map